# rest-vlc
A REST API wrapper for VLC.

## Installation
Clone the repository:

```bash
git clone https://github.com/timelessnesses/rest-vlc.git
cd rest-vlc
pip install .
# OR
pip install git+https://github.com/timelessnesses/rest-vlc.git
```

or use the production release:

```bash
pip install rest-vlc
```

## Documentation

Intellisense should self-explainatory about it, or you can go to the [https://rest-vlc.readthedocs.io/en/latest/](https://rest-vlc.readthedocs.io/en/latest/) documentation.  
Examples are in tests/ and examples/

## Features

- Asynchronous/Blocking API
- Authenication
- URL encoding automatically
- Returns dictionary instead of XML

## Status
Stable
